type Bus interface {
// Publish is the method used to publish new events. Publish(context.Context, []Event) error// Subscribe is the method used to subscribe new event handlers. Subscribe(context.Context, Type, Handler)
}
Bus defines the expected behaviour from an event bus.